  *=================================================================================================================================================
  * Date : 2024-01-23
  * Stata version : Stata 18 SE
  *
  * This program analyses simulated data accounting for DIF through a partial credit model
  *
  * ado-files needed : - pcm (version 5.5 October 25, 2023, available on gitea)
  *
  * outputs :  for N=100
  *
  *
  *================================================================================================================================================

  * Load pcm.ado
  adopath+"/home/corentin/Documents/These/Recherche/Simulations/Modules/"

  *==========================
  * Scenarios with : J=4
  *==========================

  ** Scenario 5: J = 4 items / M = 2 modalities / DIF size 0.3
  local N = "100 200 300"
  foreach Nnn in `N' {
  local Nn =  `Nnn'
  local path_data = "/home/corentin/Documents/These/Recherche/Simulations/Data/DIF/N`Nn'"
  local path_res = "/home/corentin/Documents/These/Recherche/Simulations/Analysis/DIF/N`Nn'"
  local scenarios = "A B C D E"
  foreach scen in `scenarios' {
  clear
  import delim "`path_data'/scenario_5`scen'_`Nn'.csv", encoding(ISO-8859-2)  case(preserve) clear
  rename TT tt

  * Matrice de taille 1000 * 4 items + 1 DIF + beta + std beta + 1 dif
  local nbitems = 4
  local nbdif = 1
  local taillemat = `nbitems'+`nbdif'+3
  mat outmat = J(1000,`taillemat',.)
  mat colnames outmat = "item1" "item2" "item3" "item4" "dif1" "beta" "se_beta" "dif_item_1"
  di "Scenario 5`scen' / N=`Nnn'"
  forvalues k=1/1000 {
    if (mod(`k',100)==0) {
      di "`k'/1000"
    }
    preserve
    qui keep if replication==`k'
    local difitems1=dif1
    local mod "gsem "
    forvalues i=1/`nbitems' {
      if (`i'==`difitems1') {
        local mod = "`mod'"+"(1.item`i'<-THETA@1 tt)"
      }
      else {
        local mod = "`mod'"+"(1.item`i'<-THETA@1)"
      }
    }
    local mod = "`mod'" + "(THETA<-tt), mlogit tol(0.01) iterate(500) latent(THETA) nocapslatent"
    qui `mod'
    mat V=r(table)
    mat W=V[1..2,1...]
    forvalues j=1/`nbitems' {
      if (`j'<`difitems1') {
        mat outmat[`k',`j'] = W[1,3*`j'] // items avant le premier dif
      }
      else {
        mat outmat[`k',`j'] = W[1,1+3*`j'] // items après le premier dif
      }
    }
    mat outmat[`k',`nbitems'+1] = W[1,3*`difitems1'-1] // coef de dif
    mat outmat[`k',`nbitems'+2] = W[1,3*`nbitems'+2] // beta
    mat outmat[`k',`nbitems'+3] = W[2,3*`nbitems'+2] // se beta
    mat outmat[`k',`nbitems'+4] = `difitems1' // numéro item de dif
    restore
  }
  putexcel set "`path_res'/out/5`scen'_`Nn'.xls", sheet("outmat") replace
  putexcel A1=matrix(outmat), colnames
}
}
